# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-14 17:30
# @Author : 毛鹏
from PySide6.QtCore import Signal
from PySide6.QtWidgets import QTabWidget, QWidget

from mango_ui.settings.settings import THEME


class MangoTabs(QTabWidget):
    clicked = Signal(str)

    def __init__(self):
        super().__init__()
        self.previous_index = 0
        self.setContentsMargins(0, 0, 0, 0)
        self.setStyleSheet(f"""
            QTabWidget {{
                background-color: {THEME.background_color}; /* 设置整个选项卡的底色 */
            }}
            QTabBar::tab {{
                border: none;  /* 去掉选项卡的边框 */
                padding: 6px; /* 内边距 */
            }}
            QTabBar::tab:selected {{
                background: {THEME.color.color4}; /* 选中时的背景颜色 */
            }}
            QTabBar::tab:hover {{
                background: {THEME.hover.background_color}; /* 鼠标悬停时的背景颜色 */
            }}
            QTabBar::tab {{                                
                border-right: 1px solid {THEME.border}; /* 保留按钮之间的边框 */
            }}
            QTabBar::tab:last {{
                border-right: none; /* 最后一个选项卡不显示右边框 */
            }}
            QTabWidget::pane {{
                border: 1px solid {THEME.border}; /* 底部横条 */
                border-left: none; /* 取消顶部边框 */
                border-right: none; /* 取消顶部边框 */
                border-bottom: none; /* 取消顶部边框 */
            }}
        """)

    def add_tab(self, layout, tab_name):
        new_tab = QWidget()
        new_tab.setContentsMargins(0, 0, 0, 0)
        layout.setContentsMargins(0, 5, 0, 0)
        new_tab.setLayout(layout)
        self.addTab(new_tab, tab_name)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-17 15:02
# @Author : 毛鹏
from PySide6.QtWidgets import QMainWindow

from mango_ui.widgets.layout.mango_layout import MangoVBoxLayout


class MangoMainWindow(QMainWindow):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.layout = MangoVBoxLayout(self)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-18 11:11
# @Author : 毛鹏
from mango_ui.init import *


class MangoTextEdit(QTextEdit):
    click = Signal(object)

    def __init__(self, placeholder, value: str | None = None):
        super().__init__()
        self.value = value

        if placeholder:
            self.setPlaceholderText(placeholder)

        if self.value:
            self.set_value(self.value)
        self.set_stylesheet()

    def set_value(self, text: str):
        self.setPlainText(text)

    def get_value(self):
        return self.toPlainText()

    def set_stylesheet(self):
        style = f"""
        QTextEdit {{
        	background-color: {THEME.background_color};
        	border-radius: {THEME.border_radius};
        	border: 1px solid {THEME.border};
        	padding-left: 10px;
            padding-right: 10px;
        	selection-color: {THEME.background_color};
        	selection-background-color: {THEME.color.color4};
            color: {THEME.font_color};
        }}

        QTextEdit:focus {{
            border: 1px solid {THEME.border};
            background-color: {THEME.color.color2};
        }}
        """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from mango_ui import *
from mango_ui.init import *


class DisplayPage(QWidget):
    table_menu = [
        {'name': '编辑', 'action': 'edit'},
        {'name': '删除', 'action': 'delete'}
    ]
    table_column = [
        {'key': 'id', 'name': 'ID', 'width': 7},
        {'key': 'name', 'name': '角色名称', 'width': 300},
        {'key': 'description', 'name': '角色描述', },
        {'key': 'ope', 'name': '操作', 'width': 120},
    ]

    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.page = 1
        self.page_size = 20
        self.layout = QVBoxLayout(self)
        self.table_column = [TableColumnModel(**i) for i in self.table_column]
        self.table_menu = [TableMenuItemModel(**i) for i in self.table_menu]
        self.table_widget = TableList(self.table_column, self.table_menu, )
        self.table_widget.pagination.click.connect(self.pagination_clicked)
        self.table_widget.clicked.connect(self.callback)
        self.layout.addWidget(self.table_widget)

    def show_data(self):
        data = []
        for i in range(50):
            data.append({"id": i, "create_time": "2023-07-13T12:39:57", "update_time": "2023-07-13T12:39:57",
                         "name": "开发经理",
                         "description": "管理所有开发人员权限"}
                        )
        self.table_widget.set_data(data, 10)

    def pagination_clicked(self, data):
        if data['action'] == 'prev':
            self.page = data['page']
        elif data['action'] == 'next':
            self.page = data['page']
        elif data['action'] == 'per_page':
            self.page_size = data['page']
        self.show_data()

    def callback(self, data):
        action = data.get('action')
        if action and hasattr(self, action):
            if data.get('row'):
                getattr(self, action)(row=data.get('row'))
            else:
                getattr(self, action)()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:19
# @Author : 毛鹏
from mango_ui import *
from mango_ui.init import *


class ChartsPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QHBoxLayout(self)

        self.layout_v_1 = QVBoxLayout()
        self.layout.addLayout(self.layout_v_1, 3)

        self.label = MangoLabel(f'用例执行数')
        self.pie_plot_1 = MangoPiePlot()
        self.layout_v_1.addWidget(self.pie_plot_1)
        h_layout_1 = QHBoxLayout()
        h_layout_1.addWidget(self.label, alignment=Qt.AlignCenter)  # type: ignore
        self.layout_v_1.addLayout(h_layout_1)

        self.layout_v_2 = QVBoxLayout()
        self.layout.addLayout(self.layout_v_2, 7)
        self.line_plot = MangoLinePlot('用例执行趋势图', '数量', '周')
        self.layout_v_2.addWidget(self.line_plot)

    def show_data(self):
        data = []
        response = {"api_count": [32, 19, 8, 10, 10, 12, 0, 3, 1, 1, 2, 0],
                    "ui_count": [15, 6, 1, 0, 0, 0, 0, 0, 0, 0, 2, 6]}
        data.append({'name': 'API', 'value': response.get('ui_count')})
        data.append({'name': 'UI', 'value': response.get('api_count')})
        self.line_plot.draw(data)
        self.pie_plot_1.draw([{"value": 177, "name": "前端"}, {"value": 180, "name": "接口"}])



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from mango_ui import *
from mango_ui.init import *


class MenuPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)
        self.mango_tabs = MangoTabs()
        self.layout.addWidget(self.mango_tabs)

        self.layout_1 = QVBoxLayout(self)
        self.mango_tabs.add_tab(self.layout_1, 'tabs1', )
        self.layout_3 = QVBoxLayout(self)
        self.mango_tabs.add_tab(self.layout_3, 'tabs2', )
        self.layout_2 = QVBoxLayout(self)
        self.mango_tabs.add_tab(self.layout_2, '新增')



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *
from .mango_div import MangoDiv
from .mango_title_button import MangoTitleButton
from mango_ui.models.models import TitleBarMenusModel

_is_maximized = False
_old_size = QSize()


class MangoTitleBar(QWidget):
    clicked = Signal(object)
    released = Signal(object)

    def __init__(
            self,
            parent,
            app_parent,
            logo_image=":/icons/app_icon.svg",
    ):
        super().__init__()
        self.parent = parent
        self.app_parent = app_parent
        self._logo_image = logo_image

        self._is_custom_title_bar = True

        self.title_bar_layout = QVBoxLayout(self)
        self.title_bar_layout.setContentsMargins(0, 0, 0, 0)

        self.bg = QFrame()

        self.bg_layout = QHBoxLayout(self.bg)
        self.bg_layout.setContentsMargins(10, 0, 5, 0)
        self.bg_layout.setSpacing(0)

        self.div_1 = MangoDiv(THEME.color.color5)
        self.div_2 = MangoDiv(THEME.color.color5)
        self.div_3 = MangoDiv(THEME.color.color5)

        # 带移动应用程序的左框
        self.top_logo = QLabel()
        self.top_logo_layout = QVBoxLayout(self.top_logo)
        self.top_logo_layout.setContentsMargins(0, 0, 0, 0)

        self.logo_svg = QSvgWidget()
        self.logo_svg.load(self._logo_image)
        self.top_logo_layout.addWidget(self.logo_svg, Qt.AlignCenter, Qt.AlignCenter)  # type: ignore

        # 标题标签
        self.title_label = QLabel()
        self.title_label.setAlignment(Qt.AlignVCenter)  # type: ignore
        self.title_label.setStyleSheet(f'font: {THEME.font.title_size}pt {THEME.font.family}')

        # 自定义按钮布局
        self.custom_buttons_layout = QHBoxLayout()
        self.custom_buttons_layout.setContentsMargins(0, 0, 0, 0)
        self.custom_buttons_layout.setSpacing(3)

        # 最小化按钮
        self.minimize_button = MangoTitleButton(
            self.parent,
            self.app_parent,
            tooltip_text="收起",
            icon_path=":/icons/icon_minimize.svg"
        )

        # 最大化/恢复按钮
        self.maximize_restore_button = MangoTitleButton(
            self.parent,
            self.app_parent,
            tooltip_text="最大化",
            icon_path=":/icons/icon_maximize.svg"
        )

        # 关闭按钮
        self.close_button = MangoTitleButton(
            self.parent,
            self.app_parent,
            tooltip_text="关闭",
            icon_path=":/icons/icon_close.svg"
        )

        self.title_bar_layout.addWidget(self.bg)

        self.bg.setStyleSheet(f"background-color: {THEME.color.color4}; border-radius: {THEME.border_radius};")

        self.top_logo.setMinimumWidth(40)
        self.top_logo.setMaximumWidth(40)

        def moveWindow(event):
            # 如果最大化改变为正常
            if parent.isMaximized():
                self.maximize_restore()
                # self.resize(_old_size)
                curso_x = parent.pos().x()
                curso_y = event.globalPos().y() - QCursor.pos().y()
                parent.move(curso_x, curso_y)
            # 移动窗口
            if event.buttons() == Qt.LeftButton:  # type: ignore
                parent.move(parent.pos() + event.globalPos() - parent.drag_pos)
                parent.drag_pos = event.globalPos()
                event.accept()

        # 移动应用程序小部件
        if self._is_custom_title_bar:
            self.top_logo.mouseMoveEvent = moveWindow
            self.div_1.mouseMoveEvent = moveWindow
            self.title_label.mouseMoveEvent = moveWindow
            self.div_2.mouseMoveEvent = moveWindow
            self.div_3.mouseMoveEvent = moveWindow

        # 最大化/恢复
        if self._is_custom_title_bar:
            self.top_logo.mouseDoubleClickEvent = self.maximize_restore
            self.div_1.mouseDoubleClickEvent = self.maximize_restore
            self.title_label.mouseDoubleClickEvent = self.maximize_restore
            self.div_2.mouseDoubleClickEvent = self.maximize_restore

        # 添加按钮按钮

        # 功能
        self.minimize_button.released.connect(lambda: parent.showMinimized())
        self.maximize_restore_button.released.connect(lambda: self.maximize_restore())
        self.close_button.released.connect(lambda: parent.close())

        # 添加控件到布局
        self.bg_layout.addWidget(self.top_logo)

        # 添加占位符 div_1
        self.bg_layout.addWidget(self.div_1)
        self.bg_layout.setStretch(self.bg_layout.indexOf(self.div_1), -1)  # 设置 div_1 的伸缩因子

        # 添加 title_label，靠近 top_logo
        self.bg_layout.addWidget(self.title_label)

        # 添加占位符 div_2
        self.bg_layout.addWidget(self.div_2)
        self.bg_layout.setStretch(self.bg_layout.indexOf(self.div_2), 1)  # 设置 div_2 的伸缩因子

        # 添加自定义按钮布局
        self.bg_layout.addLayout(self.custom_buttons_layout)

        # ADD Buttons
        if self._is_custom_title_bar:
            self.bg_layout.addWidget(self.minimize_button)
            self.bg_layout.addWidget(self.maximize_restore_button)
            self.bg_layout.addWidget(self.close_button)

    def add_menus(self, parameters: list[TitleBarMenusModel]):
        if parameters is None:
            return
        for parameter in parameters:
            self.menu = MangoTitleButton(
                self.parent,
                self.app_parent,
                btn_id=parameter.btn_id,
                tooltip_text=parameter.btn_tooltip,
                icon_path=parameter.btn_icon,
                is_active=parameter.is_active
            )
            self.menu.clicked.connect(self.btn_clicked)
            self.menu.released.connect(self.btn_released)

            self.custom_buttons_layout.addWidget(self.menu)

        if self._is_custom_title_bar:
            self.custom_buttons_layout.addWidget(self.div_3)

    # 标题栏菜单发出信号
    def btn_clicked(self):
        self.clicked.emit(self.menu)

    def btn_released(self):
        self.released.emit(self.menu)

    # 设置标题栏文本
    def set_title(self, title):
        self.title_label.setText(title)

    # 最大化并恢复父窗口
    def maximize_restore(self, e=None):
        global _is_maximized
        global _old_size

        # 更改UI并调整夹点大小
        def change_ui():
            if _is_maximized:
                self.parent.central_widget_layout.setContentsMargins(0, 0, 0, 0)  # type: ignore
                self.parent.window.set_stylesheet(border_radius=0, border_size=0)  # type: ignore
                self.maximize_restore_button.set_icon(":/icons/icon_restore.svg")
            else:
                self.parent.central_widget_layout.setContentsMargins(10, 10, 10, 10)  # type: ignore
                self.parent.window.set_stylesheet(border_radius=10, border_size=2)  # type: ignore
                self.maximize_restore_button.set_icon(":/icons/icon_maximize.svg")

        # 检查事件
        if self.parent.isMaximized():
            _is_maximized = False
            self.parent.showNormal()
            change_ui()
        else:
            _is_maximized = True
            _old_size = QSize(self.parent.width(), self.parent.height())
            self.parent.showMaximized()
            change_ui()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
import webbrowser

from mango_ui.init import *
from mango_ui.models.models import MenusModel, AppConfig
from mango_ui.widgets.menu import MangoMenu
from mango_ui.widgets.miscellaneous.mango_credits import MangoCredits
from mango_ui.widgets.miscellaneous.mango_grips import MangoGrips
from mango_ui.widgets.title_bar.mango_title_bar import MangoTitleBar
from mango_ui.widgets.window.main_window.main_1.pages_window import PagesWindow
from mango_ui.widgets.window.mango_frame import MangoFrame


class UIWindow(QMainWindow):
    clicked = Signal(object)

    def __init__(self, style: AppConfig, menus: MenusModel, page_dict, l=None, **kwargs):
        super().__init__()
        self.style = style
        self.menus = menus
        self.loop = l
        self.page_dict = page_dict
        self.kwargs = kwargs
        self.setWindowTitle(self.style.app_name)
        screen = QGuiApplication.primaryScreen().geometry()
        width = int(screen.width() * 0.6)
        height = int(screen.height() * 0.7)
        self.resize(width, height)
        self.setMinimumSize(int(width * 0.8), int(height * 0.8))

        self.central_widget = QWidget()
        self.central_widget.setStyleSheet(f'''
            font: {THEME.font.text_size}pt "{THEME.font.family}";
            color: {THEME.font_color};
        ''')
        self.central_widget_layout = QVBoxLayout(self.central_widget)
        if self.style.custom_title_bar:
            self.central_widget_layout.setContentsMargins(10, 10, 10, 10)
        else:
            self.central_widget_layout.setContentsMargins(0, 0, 0, 0)
        self.setCentralWidget(self.central_widget)

        self.window = MangoFrame(self)
        if not self.style.custom_title_bar:
            self.window.set_stylesheet(border_radius=0, border_size=0)
        self.central_widget_layout.addWidget(self.window)

        self.menus_ui()
        self.right_app_frame = QFrame()
        self.right_app_layout = QVBoxLayout(self.right_app_frame)
        self.right_app_layout.setContentsMargins(3, 3, 3, 3)
        self.right_app_layout.setSpacing(6)
        self.window.layout.addWidget(self.right_app_frame)
        self.title_bar_ui()
        self.content_ui()
        self.bottom_ui()

    def menus_ui(self):
        self.left_menu_frame = QFrame()
        self.left_menu_frame.setMaximumSize(
            self.style.lef_menu_size.minimum + (self.style.left_menu_content_margins * 2), 17280)
        self.left_menu_frame.setMinimumSize(
            self.style.lef_menu_size.minimum + (self.style.left_menu_content_margins * 2), 0)
        self.left_menu_layout = QHBoxLayout(self.left_menu_frame)
        self.left_menu_layout.setContentsMargins(3, 3, 3, 3)
        self.left_menu = MangoMenu(
            parent=self.left_menu_frame,
            app_parent=self.central_widget,
        )
        self.left_menu.add_menus(self.menus.left_menus)
        self.left_menu.clicked.connect(self.btn_clicked)
        self.left_menu.released.connect(self.btn_released)
        self.left_menu_layout.addWidget(self.left_menu)
        self.window.layout.addWidget(self.left_menu_frame)

    def title_bar_ui(self):
        self.title_bar_frame = QFrame()
        self.title_bar_frame.setMinimumHeight(40)
        self.title_bar_frame.setMaximumHeight(40)
        self.title_bar_layout = QVBoxLayout(self.title_bar_frame)
        self.title_bar_layout.setContentsMargins(0, 0, 0, 0)

        self.title_bar = MangoTitleBar(self, self.central_widget, )
        self.title_bar.add_menus(self.menus.title_bar_menus)
        self.title_bar.clicked.connect(self.title_ber_but_clicked)
        self.title_bar.released.connect(self.btn_released)

        self.title_bar_layout.addWidget(self.title_bar)
        self.right_app_layout.addWidget(self.title_bar_frame)

        if self.style.custom_title_bar:
            self.title_bar.set_title(self.style.app_name)
            self.setWindowFlag(Qt.FramelessWindowHint)  # type: ignore
            self.setAttribute(Qt.WA_TranslucentBackground)  # type: ignore
            self.left_grip = MangoGrips(self, "left", )
            self.right_grip = MangoGrips(self, "right", )
            self.top_grip = MangoGrips(self, "top", )
            self.bottom_grip = MangoGrips(self, "bottom", )
            self.top_left_grip = MangoGrips(self, "top_left", )
            self.top_right_grip = MangoGrips(self, "top_right", )
            self.bottom_left_grip = MangoGrips(self, "bottom_left", )
            self.bottom_right_grip = MangoGrips(self, "bottom_right", )

    def content_ui(self):
        self.content_area_frame = QFrame()
        self.content_area_layout = QHBoxLayout(self.content_area_frame)
        self.content_area_layout.setContentsMargins(0, 0, 0, 0)
        self.content_area_layout.setSpacing(0)

        self.content_area_left_frame = QFrame()
        self.load_pages = PagesWindow(self, self.content_area_left_frame, self.page_dict)

        self.load_pages.set_page(self.kwargs.get('page') if self.kwargs.get('page') else 'home')
        self.content_area_layout.addWidget(self.content_area_left_frame)
        self.right_app_layout.addWidget(self.content_area_frame)

    def bottom_ui(self):
        self.credits_frame = QFrame()
        self.credits_frame.setMinimumHeight(26)
        self.credits_frame.setMaximumHeight(26)
        self.credits_layout = QVBoxLayout(self.credits_frame)
        self.credits_layout.setContentsMargins(0, 0, 0, 0)
        self.credits = MangoCredits(self.style.copyright, self.style.version)
        self.credits_layout.addWidget(self.credits)
        self.right_app_layout.addWidget(self.credits_frame)

    def btn_released(self):
        btn = self.__setup_btn()

    @staticmethod
    def animate_frame(parent, frame, duration=300):
        """
        从上往下展开 QFrame 的动画效果。

        :param frame: 要显示的 QFrame
        :param duration: 动画持续时间（毫秒）
        """
        animation = QPropertyAnimation(parent, b"minimumWidth")
        animation.stop()
        frame.show()
        animation.setTargetObject(frame)
        animation.setEasingCurve(QEasingCurve.InOutCubic)
        animation.setDuration(duration)
        animation.start()

    def title_ber_but_clicked(self):
        btn = self.__setup_btn()
        if btn.url:
            webbrowser.open(btn.url)
            return
        btn_name = btn.objectName()
        self.clicked.emit(btn_name)

    def btn_clicked(self):
        btn = self.__setup_btn()
        if btn.url:
            webbrowser.open(btn.url)
            return
        btn_name = btn.objectName()
        for submenus_obj in self.left_menu.list_button_frame:
            if submenus_obj['parent_btn_id'] == btn_name:
                if submenus_obj['frame_object'].isHidden():
                    self.left_menu.toggle_animation(False)
                    self.animate_frame(self.left_menu.parent, submenus_obj['frame_object'])
                else:
                    submenus_obj['frame_object'].hide()
            elif not submenus_obj['frame_object'].isHidden() and btn_name not in submenus_obj['btn_id_list']:
                submenus_obj['frame_object'].hide()
        self.__set_page(btn_name)

    def __set_page(self, btn_name):
        self.left_menu.deselect_all_tab()
        for k, v in self.load_pages.page_dict.items():
            if btn_name == k:
                self.left_menu.select_only_one(k)
                self.load_pages.set_page(k)

    def get_title_bar_btn(self, object_name):
        return self.title_bar_frame.findChild(QPushButton, object_name)

    def __setup_btn(self):
        if self.title_bar.sender() is not None:
            return self.title_bar.sender()
        elif self.left_menu.sender() is not None:
            return self.left_menu.sender()

    def resize_grips(self):
        if self.style.custom_title_bar:
            self.left_grip.setGeometry(5, 10, 10, self.height())
            self.right_grip.setGeometry(self.width() - 15, 10, 10, self.height())
            self.top_grip.setGeometry(5, 5, self.width() - 10, 10)
            self.bottom_grip.setGeometry(5, self.height() - 15, self.width() - 10, 10)
            self.top_left_grip.setGeometry(self.width() - 20, 5, 15, 15)
            self.top_right_grip.setGeometry(self.width() - 20, 5, 15, 15)
            self.bottom_left_grip.setGeometry(5, self.height() - 20, 15, 15)
            self.bottom_right_grip.setGeometry(self.width() - 20, self.height() - 20, 15, 15)

    def set_page(self, page: str, data: dict | None = None):
        self.load_pages.set_page(page, data)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 21:24
# @Author : 毛鹏

from mango_ui import *
from mango_ui.init import *


class InputPage(QWidget):
    cascade_data = [{"value": 8, "label": "智投", "parameter": None, "children": [
        {"value": 13, "label": "新智投", "parameter": None,
         "children": [{"value": 107, "label": "登录", "parameter": None, "children": []},
                      {"value": 106, "label": "项目", "parameter": None, "children": []},
                      {"value": 105, "label": "小红书实时看版", "parameter": None, "children": []},
                      {"value": 104, "label": "报数助手", "parameter": None, "children": []},
                      {"value": 103, "label": "用户中心", "parameter": None, "children": []},
                      {"value": 102, "label": "首页", "parameter": None, "children": []}]},
        {"value": 6, "label": "老智投", "parameter": None,
         "children": [{"value": 93, "label": "小红星日报-搜索推广", "parameter": None, "children": []},
                      {"value": 92, "label": "小红星日报-信息流", "parameter": None, "children": []},
                      {"value": 91, "label": "登录", "parameter": None, "children": []}]}]},
                    {"value": 4, "label": "DESK", "parameter": None,
                     "children": [{"value": 4, "label": "ZDesk-二代", "parameter": None, "children": []},
                                  {"value": 1, "label": "ZDesk-低代码", "parameter": None,
                                   "children": [{"value": 81, "label": "收票单", "parameter": None, "children": []},
                                                {"value": 80, "label": "供应商管理", "parameter": None, "children": []},
                                                {"value": 79, "label": "供应商付款单", "parameter": None,
                                                 "children": []},
                                                {"value": 78, "label": "垫款管理", "parameter": None, "children": []},
                                                {"value": 77, "label": "低代码后台", "parameter": None, "children": []},
                                                {"value": 76, "label": "二代-充值申请", "parameter": None,
                                                 "children": []},
                                                {"value": 75, "label": "二代系统", "parameter": None, "children": []},
                                                {"value": 74, "label": "保证金付款单", "parameter": None,
                                                 "children": []},
                                                {"value": 73, "label": "供应商政策", "parameter": None, "children": []},
                                                {"value": 72, "label": "供应商列表", "parameter": None, "children": []},
                                                {"value": 71, "label": "常规授信设置", "parameter": None,
                                                 "children": []},
                                                {"value": 70, "label": "信用评级设置", "parameter": None,
                                                 "children": []},
                                                {"value": 69, "label": "临时垫款设置", "parameter": None,
                                                 "children": []},
                                                {"value": 68, "label": "巨量行业对应关系", "parameter": None,
                                                 "children": []},
                                                {"value": 67, "label": "销售指导政策设置", "parameter": None,
                                                 "children": []},
                                                {"value": 66, "label": "开户银行列表", "parameter": None,
                                                 "children": []},
                                                {"value": 65, "label": "结算方式推单设置", "parameter": None,
                                                 "children": []},
                                                {"value": 64, "label": "系统单据链路设置", "parameter": None,
                                                 "children": []},
                                                {"value": 63, "label": "线索池管理", "parameter": None, "children": []},
                                                {"value": 62, "label": "媒体平台/业务线/执行部门对应关系",
                                                 "parameter": None, "children": []},
                                                {"value": 61, "label": "供应商服务费用单", "parameter": None,
                                                 "children": []},
                                                {"value": 60, "label": "其他服务费用单", "parameter": None,
                                                 "children": []},
                                                {"value": 59, "label": "运营服务费用单", "parameter": None,
                                                 "children": []},
                                                {"value": 58, "label": "运营结算", "parameter": None, "children": []},
                                                {"value": 57, "label": "勾稽", "parameter": None, "children": []},
                                                {"value": 56, "label": "其他结算", "parameter": None, "children": []},
                                                {"value": 55, "label": "项目结算", "parameter": None, "children": []},
                                                {"value": 54, "label": "消耗结算", "parameter": None, "children": []},
                                                {"value": 53, "label": "充值结算", "parameter": None, "children": []},
                                                {"value": 52, "label": "消耗匹配明细", "parameter": None,
                                                 "children": []},
                                                {"value": 51, "label": "消耗同步", "parameter": None, "children": []},
                                                {"value": 50, "label": "营销点评列表", "parameter": None,
                                                 "children": []},
                                                {"value": 49, "label": "媒体账户关系组", "parameter": None,
                                                 "children": []},
                                                {"value": 48, "label": "媒体账户列表", "parameter": None,
                                                 "children": []},
                                                {"value": 47, "label": "媒体账户绑定", "parameter": None,
                                                 "children": []},
                                                {"value": 42, "label": "预收款管理", "parameter": None, "children": []},
                                                {"value": 31, "label": "合同管理", "parameter": None, "children": []},
                                                {"value": 30, "label": "非充值模块", "parameter": None, "children": []},
                                                {"value": 29, "label": "流水管理", "parameter": None, "children": []},
                                                {"value": 27, "label": "商机管理", "parameter": None, "children": []},
                                                {"value": 26, "label": "客户管理", "parameter": None, "children": []},
                                                {"value": 25, "label": "客资管理", "parameter": None, "children": []},
                                                {"value": 22, "label": "充值业务", "parameter": None, "children": []},
                                                {"value": 13, "label": "登录", "parameter": None, "children": []}]}]},
                    {"value": 3, "label": "CDXP", "parameter": None,
                     "children": [{"value": 11, "label": "GrowKnows", "parameter": None, "children": []}]},
                    {"value": 1, "label": "AIGC", "parameter": None,
                     "children": [{"value": 12, "label": "AIGC-SaaS", "parameter": None, "children": []},
                                  {"value": 10, "label": "AIGC-TMS", "parameter": None, "children": []},
                                  {"value": 7, "label": "AIGC日报", "parameter": None,
                                   "children": [{"value": 35, "label": "首页", "parameter": None, "children": []},
                                                {"value": 11, "label": "笔记历史", "parameter": None, "children": []},
                                                {"value": 10, "label": "家具", "parameter": None, "children": []},
                                                {"value": 9, "label": "装修", "parameter": None, "children": []},
                                                {"value": 8, "label": "配饰", "parameter": None, "children": []},
                                                {"value": 7, "label": "服饰", "parameter": None, "children": []},
                                                {"value": 6, "label": "品牌管理", "parameter": None, "children": []},
                                                {"value": 5, "label": "创作记录", "parameter": None, "children": []},
                                                {"value": 4, "label": "关键字", "parameter": None, "children": []},
                                                {"value": 3, "label": "信息流", "parameter": None, "children": []},
                                                {"value": 2, "label": "日报生成", "parameter": None, "children": []},
                                                {"value": 1, "label": "登录", "parameter": None, "children": []}]},
                                  {"value": 5, "label": "AIGC-SaaS-C端", "parameter": None,
                                   "children": [{"value": 97, "label": "文生图", "parameter": None, "children": []},
                                                {"value": 96, "label": "权益兑换", "parameter": None, "children": []},
                                                {"value": 95, "label": "智豆管理", "parameter": None, "children": []},
                                                {"value": 94, "label": "会员权益", "parameter": None, "children": []},
                                                {"value": 89, "label": "AI课堂", "parameter": None, "children": []},
                                                {"value": 88, "label": "知识库", "parameter": None, "children": []},
                                                {"value": 87, "label": "历史记录", "parameter": None, "children": []},
                                                {"value": 86, "label": "应用", "parameter": None, "children": []},
                                                {"value": 82, "label": "登录", "parameter": None, "children": []}]},
                                  {"value": 3, "label": "AIGC-WEB", "parameter": None, "children": []},
                                  {"value": 2, "label": "AIGC-SaaS", "parameter": None,
                                   "children": [{"value": 85, "label": "AI课堂", "parameter": None, "children": []},
                                                {"value": 84, "label": "历史记录", "parameter": None, "children": []},
                                                {"value": 83, "label": "应用", "parameter": None, "children": []},
                                                {"value": 45, "label": "语义搜索", "parameter": None, "children": []},
                                                {"value": 43, "label": "模版市场", "parameter": None, "children": []},
                                                {"value": 34, "label": "Flow列表", "parameter": None, "children": []},
                                                {"value": 33, "label": "所有模板", "parameter": None, "children": []},
                                                {"value": 32, "label": "模板管理", "parameter": None, "children": []},
                                                {"value": 24, "label": "创作模板", "parameter": None, "children": []},
                                                {"value": 21, "label": "小红书运营百事通", "parameter": None,
                                                 "children": []},
                                                {"value": 20, "label": "知识库", "parameter": None, "children": []},
                                                {"value": 19, "label": "文档分类", "parameter": None, "children": []},
                                                {"value": 18, "label": "个人中心", "parameter": None, "children": []},
                                                {"value": 17, "label": "首页", "parameter": None, "children": []},
                                                {"value": 16, "label": "文档库", "parameter": None, "children": []},
                                                {"value": 15, "label": "服饰达人", "parameter": None, "children": []},
                                                {"value": 14, "label": "登录", "parameter": None, "children": []}]}]}]
    combo_box_data = [{"id": 0, "name": "高"}, {"id": 1, "name": "中"}, {"id": 2, "name": "低"},
                      {"id": 3, "name": "极低"}]

    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)

        self.mango_time_edit = MangoTimeEdit()
        self.layout.addWidget(self.mango_time_edit)

        self.mango_cascade = MangoCascade('多级选择', [CascaderModel(**i) for i in self.cascade_data])
        self.layout.addWidget(self.mango_cascade)

        self.mango_checkbox = MangoCheckBox()
        self.layout.addWidget(self.mango_checkbox)

        self.mango_combobox = MangoComboBox('选择框', [ComboBoxDataModel(**i) for i in self.combo_box_data])
        self.layout.addWidget(self.mango_combobox)

        # self.mango_icon_button = MangoIconButton(self, self)
        # self.layout.addWidget(self.mango_icon_button)

        self.mango_line_edit = MangoLineEdit('请输入内容')
        self.layout.addWidget(self.mango_line_edit)

        self.mango_push_button = MangoPushButton('按钮')
        self.layout.addWidget(self.mango_push_button)

        self.mango_slider = MangoSlider()
        self.layout.addWidget(self.mango_slider)

        self.mango_text_edit = MangoTextEdit('多行输入框')
        self.layout.addWidget(self.mango_text_edit)

        self.mango_toggle = MangoToggle()
        self.layout.addWidget(self.mango_toggle)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-02 20:57
# @Author : 毛鹏
from mango_ui import *
from mango_ui.init import *


class HomePage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)
        self.layout.addWidget(MangoLabel('首页示例'))



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-31 9:51
# @Author : 毛鹏

from mango_ui.pages import *
from mango_ui.settings.settings import STYLE, MENUS


def main():
    page_dict = {
        'home': HomePage,
        'component': ComponentPage,
        'feedback': FeedbackPage,
        'container': ContainerPage,
        'charts': ChartsPage,
        'display': DisplayPage,
        'graphics': GraphicsPage,
        'input': InputPage,
        'layout': LayoutPage,
        'layout_page_1': Layout1Page,
        'layout_page_2': Layout2Page,
        'component_page_3': Layout3Page,
        'component_page_4': Layout4Page,
        'menu': MenuPage,
        'miscellaneous': MiscellaneousPage,
        'window': WindowPage,
    }

    app = QApplication([])
    login_window = MangoMainWindow(STYLE, MENUS, page_dict)
    login_window.show()
    app.exec()


main()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-19 11:29
# @Author : 毛鹏

from mango_ui import *
from mango_ui.init import *


class ContainerPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)

        for i in range(10):
            self.layout_g = QGridLayout()
            self.mango_card = MangoCard(self.layout_g)
            self.layout.addWidget(self.mango_card)
            self.layout_g.addWidget(MangoLabel(f'卡片--{i}'))



import sys
from PySide6.QtWidgets import QApplication, QMainWindow, QVBoxLayout, QPushButton, QFrame, QWidget
from PySide6.QtCore import QPropertyAnimation


def animate_frame(frame, duration=300):
    """
    从上往下展开或收起 QFrame 的动画效果。

    :param frame: 要显示的 QFrame
    :param duration: 动画持续时间（毫秒）
    """
    if frame.isVisible():
        animation = QPropertyAnimation(frame, b"maximumHeight")
        animation.setDuration(duration)
        animation.setStartValue(frame.sizeHint().height())  # 动画开始时的高度
        animation.setEndValue(0)  # 动画结束时的高度
        animation.start()
        animation.finished.connect(frame.hide)  # 动画结束后隐藏框架
    else:
        frame.setMaximumHeight(0)  # 设置初始高度为0
        frame.show()  # 显示框架
        animation = QPropertyAnimation(frame, b"maximumHeight")
        animation.setDuration(duration)
        animation.setStartValue(0)  # 动画开始时的高度
        animation.setEndValue(frame.sizeHint().height())  # 动画结束时的高度
        animation.start()  # 启动动画


class MainWindow(QMainWindow):
    def __init__(self):
        super().__init__()

        self.setWindowTitle("动画测试")
        self.setGeometry(100, 100, 300, 400)

        main_widget = QWidget(self)
        self.setCentralWidget(main_widget)

        layout = QVBoxLayout(main_widget)

        # 创建一个按钮来触发动画
        toggle_button = QPushButton("切换菜单", self)
        toggle_button.clicked.connect(self.toggle_menu)
        layout.addWidget(toggle_button)

        # 创建一个 QFrame
        self.menu_frame = QFrame(self)
        self.menu_frame.setStyleSheet("background-color: lightgray;")
        self.menu_frame.setContentsMargins(0, 0, 0, 0)
        self.menu_frame.setMaximumHeight(0)  # 初始高度为0
        self.menu_frame.hide()  # 初始隐藏

        # 在 QFrame 中添加一些内容
        menu_layout = QVBoxLayout(self.menu_frame)
        for i in range(5):
            menu_button = QPushButton(f"菜单项 {i + 1}", self.menu_frame)
            menu_layout.addWidget(menu_button)

        layout.addWidget(self.menu_frame)

    def toggle_menu(self):
        animate_frame(self.menu_frame)  # 调用动画显示函数


if __name__ == "__main__":
    app = QApplication(sys.argv)
    window = MainWindow()
    window.show()
    sys.exit(app.exec())



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-01 14:27
# @Author : 毛鹏
from mango_ui import *
from mango_ui.init import *


class FeedbackPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)
        self.layout_h = QHBoxLayout()
        self.success = MangoPushButton('成功')
        self.success.clicked.connect(self.success_click)
        self.layout_h.addWidget(self.success)
        self.warning = MangoPushButton('警告')
        self.warning.clicked.connect(self.warning_click)
        self.layout_h.addWidget(self.warning)
        self.info = MangoPushButton('提示')
        self.info.clicked.connect(self.info_click)
        self.layout_h.addWidget(self.info)
        self.error = MangoPushButton('失败')
        self.error.clicked.connect(self.error_click)
        self.layout_h.addWidget(self.error)
        self.layout.addLayout(self.layout_h)
        self.layout_h_2 = QHBoxLayout()
        self.success_msg = MangoPushButton('成功')
        self.success_msg.clicked.connect(self.success_message)
        self.layout_h_2.addWidget(self.success_msg)
        self.warning_msg = MangoPushButton('警告')
        self.warning_msg.clicked.connect(self.warning_message)
        self.layout_h_2.addWidget(self.warning_msg)
        self.info_msg = MangoPushButton('提示')
        self.info_msg.clicked.connect(self.info_message)
        self.layout_h_2.addWidget(self.info_msg)
        self.error_msg = MangoPushButton('失败')
        self.error_msg.clicked.connect(self.error_message)
        self.layout_h_2.addWidget(self.error_msg)
        self.layout.addLayout(self.layout_h_2)

    def success_click(self):
        success_notification(self, '这是一个成功的提示！')

    def info_click(self):
        info_notification(self, '这是一个info的提示！')

    def warning_click(self):
        warning_notification(self, '这是一个警告的提示！')

    def error_click(self):
        error_notification(self, '这是一个失败的提示！')

    def info_message(self):
        info_message(self, '这是一个info的提示这是一个info的提示')

    def error_message(self):
        error_message(self, '这是一个失败的提示')

    def success_message(self):
        success_message(self, '这是一个成功的提示')

    def warning_message(self):
        warning_message(self, '这是一个警告的提示')

    def show_data(self):
        pass



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-19 11:29
# @Author : 毛鹏
from mango_ui.init import *


class MangoCard(QWidget):
    clicked = Signal(str)

    def __init__(self, layout, title: str | None = None, parent=None, name='', **kwargs):
        super().__init__(parent)
        self.name = name  # 唯一标识
        self.kwargs = kwargs
        layout.setContentsMargins(10, 0, 10, 0)

        self.layout = QVBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)

        self.frame = QFrame()
        if title:
            self.frame_layout = QVBoxLayout()
            self.frame_layout.setContentsMargins(0, 0, 0, 0)
            self.frame.setLayout(self.frame_layout)
            title_label = QLabel(title)
            font = QFont()
            font.setPointSize(18)  # 设置字体大小
            font.setBold(True)  # 设置为粗体
            title_label.setFont(font)
            self.frame_layout.addWidget(title_label, 1)
            self.frame.setLayout(self.frame_layout)
            self.frame_layout_h = QHBoxLayout()
            self.frame_layout_h.setContentsMargins(10, 0, 0, 0)
            self.frame_layout_h.addLayout(layout)
            self.frame_layout.addLayout(self.frame_layout_h, 9)
        else:
            self.frame.setLayout(layout)
        self.layout.addWidget(self.frame)

        self.setLayout(self.layout)
        self.set_stylesheet()

    def enterEvent(self, event):
        if self.name:
            self.setCursor(Qt.PointingHandCursor)  # type: ignore
            super().enterEvent(event)

    def leaveEvent(self, event):
        if self.name:
            self.setCursor(Qt.ArrowCursor)  # type: ignore
            super().leaveEvent(event)

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:  # type: ignore
            self.clicked.emit(self.name)  # 发送点击信号
        super().mousePressEvent(event)  # 确保调用父类方法

    def set_stylesheet(self):
        self.setObjectName('mangoCard')
        background_color = self.kwargs.get('background_color')
        if background_color is None:
            background_color = THEME.card_color
        style = f"""
        QWidget#mangoCard {{
            background-color: {background_color};
            border: 1px solid {background_color};
            border-radius: {THEME.border_radius};
            padding: 10px;
        }}
        QWidget#mangoCard > QFrame {{
            background-color: {background_color};
            border: 1px solid {background_color};
            border-radius: {THEME.border_radius};
            padding: 10px;
        }}

        """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-17 14:55
# @Author : 毛鹏
from PySide6.QtCore import Qt
from PySide6.QtWidgets import QVBoxLayout, QHBoxLayout, QFormLayout, QGridLayout


class MangoVBoxLayout(QVBoxLayout):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setAlignment(Qt.AlignTop)  # type: ignore


class MangoHBoxLayout(QHBoxLayout):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setAlignment(Qt.AlignLeft)  # type: ignore


class MangoFormLayout(QFormLayout):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setAlignment(Qt.AlignLeft)  # type: ignore


class MangoGridLayout(QGridLayout):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setAlignment(Qt.AlignLeft)  # type: ignore



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-30 18:15
# @Author : 毛鹏
import os

from PySide6.QtGui import QCursor

from mango_ui.models.models import MenusModel, AppConfig
from mango_ui.widgets.window.main_window.main_1.ui_window import UIWindow

os.environ["QT_FONT_DPI"] = "96"


class MangoMain1Window(UIWindow):
    def __init__(self, style: AppConfig, menus: MenusModel, page_dict, l=None, **kwargs):
        super().__init__(style, menus, page_dict, l, **kwargs)

    def resizeEvent(self, event):
        self.resize_grips()

    def mousePressEvent(self, event):
        self.drag_pos = QCursor.pos()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏

from mango_ui.init import *


class MangoFrame(QFrame):

    def __init__(
            self,
            parent,
            layout=Qt.Vertical,  # type: ignore
            margin=0,
            spacing=2,
            text_font="9pt 'Segoe UI'",
            enable_shadow=True
    ):
        super().__init__()
        self.parent = parent
        self.layout = layout
        self.margin = margin
        self.text_font = text_font
        self.enable_shadow = enable_shadow

        self.setObjectName("pod_bg_app")

        self.set_stylesheet()

        if layout == Qt.Vertical:  # type: ignore
            self.layout = QHBoxLayout(self)
        else:
            self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(margin, margin, margin, margin)
        self.layout.setSpacing(spacing)

        if enable_shadow:
            self.shadow = QGraphicsDropShadowEffect()
            self.shadow.setBlurRadius(20)
            self.shadow.setXOffset(0)
            self.shadow.setYOffset(0)
            self.shadow.setColor(QColor(0, 0, 0, 160))
            self.setGraphicsEffect(self.shadow)

    def set_stylesheet(self, border_radius=None, border_size=None):

        style = f"""
            #pod_bg_app {{
                background-color: {THEME.background_color};
                border-radius: {THEME.border_radius};
                border: {border_size if border_size else '1'}px solid {border_radius if border_radius else THEME.border};
            }}
            QFrame {{ 
                color: {THEME.font_color};
                font: {self.text_font};
            }}
            """
        self.setStyleSheet(style)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-10-16 15:46
# @Author : 毛鹏
import json


class WidgetTool:

    @classmethod
    def remove_layout(cls, layout):
        while layout.count():
            item = layout.takeAt(0)
            if item.widget():
                item.widget().deleteLater()
            elif item.layout():
                cls.remove_layout(item.layout())
                item.layout().deleteLater()

    @staticmethod
    def json_init_data(data: str | dict | list | None, save: bool = False):
        if not save:
            if data is None:
                return data
            elif isinstance(data, str):
                try:
                    parsed_data = json.loads(data)
                    return json.dumps(parsed_data, ensure_ascii=False, indent=4)
                except json.JSONDecodeError:
                    return data
            elif isinstance(data, dict) or isinstance(data, list):
                return json.dumps(data, ensure_ascii=False, indent=4)
        else:
            if data is None or data == '':
                return None
            else:
                return json.loads(data)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-11-17 12:42
# @Author : 毛鹏

from PySide6.QtCore import QRect, Qt, QPoint
from PySide6.QtGui import QColor, QPainter
from PySide6.QtWidgets import QComboBox, QGraphicsDropShadowEffect, QLabel

from mango_ui.settings.settings import THEME


class MangoDropdownMenu(QComboBox):
    def __init__(self, app_parent, options, tooltip_text='', btn_id=None):
        super().__init__(app_parent)
        self.setObjectName(btn_id)
        self.setCursor(Qt.PointingHandCursor)

        self.options = options
        self.tooltip_text = tooltip_text
        self.tooltip = _ToolTip(
            app_parent,
            tooltip_text,
            THEME.color.color4,
            THEME.color.color5,
            THEME.font_color
        )
        self.tooltip.hide()

        self.setStyleSheet("QComboBox {"
                           "border: 2px solid " + THEME.color.color4 + ";"
                                                                       "border-radius: 8px;"
                                                                       "padding: 5px;"
                                                                       "background-color: " + THEME.background_color + ";"
                                                                                                                       "color: " + THEME.font_color + ";"
                                                                                                                                                      "}"
                                                                                                                                                      "QComboBox::drop-down {"
                                                                                                                                                      "subcontrol-origin: padding;"
                                                                                                                                                      "subcontrol-position: top right;"
                                                                                                                                                      "width: 20px;"
                                                                                                                                                      "border-left-width: 0px;"
                                                                                                                                                      "border-left-color: transparent;"
                                                                                                                                                      "border-left-style: solid;"
                                                                                                                                                      "border-radius: 0px;"
                                                                                                                                                      "}"
                           )

        self.addItems(options)

    def enterEvent(self, event):
        self.tooltip.move_tooltip()
        self.tooltip.show()

    def leaveEvent(self, event):
        self.tooltip.hide()

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.tooltip.hide()
            super().mousePressEvent(event)

    def paintEvent(self, event):
        p = QPainter(self)
        p.setRenderHint(QPainter.Antialiasing)
        p.setPen(Qt.NoPen)

        # 绘制背景
        rect = QRect(0, 0, self.width(), self.height())
        p.setBrush(QColor(THEME.color.color4))
        p.drawRoundedRect(rect, 8, 8)

        # 绘制文本
        p.setPen(QColor(THEME.font_color))
        p.drawText(rect, Qt.AlignVCenter | Qt.AlignLeft, self.currentText())

        p.end()


class _ToolTip(QLabel):
    style_tooltip = """ 
    QLabel {{		
        background-color: {_dark_one};	
        color: {_text_foreground};
        padding-left: 10px;
        padding-right: 10px;
        border-radius: 17px;
        border: 0px solid transparent;
        border-left: 3px solid {_context_color};
        font: 800 9pt "Segoe UI";
    }}
    """

    def __init__(self, parent, tooltip, dark_one, context_color, text_foreground):
        QLabel.__init__(self)

        style = self.style_tooltip.format(
            _dark_one=dark_one,
            _context_color=context_color,
            _text_foreground=text_foreground
        )
        self.setObjectName(u"label_tooltip")
        self.setStyleSheet(style)
        self.setMinimumHeight(34)
        self.setParent(parent)
        self.setText(tooltip)
        self.adjustSize()

        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(30)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 80))
        self.setGraphicsEffect(self.shadow)

    def move_tooltip(self):
        gp = self.parent().mapToGlobal(QPoint(0, 0))
        pos = self.parent().mapFromGlobal(gp)
        pos_x = pos.x() + self.parent().width() + 5
        pos_y = pos.y() + (self.parent().height() - self.height()) // 2
        self.move(pos_x, pos_y)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from mango_ui.init import *


class MangoCredits(QWidget):
    def __init__(self, copyright, version, ):
        super().__init__()
        self.copyright = copyright
        self.version = version

        self.widget_layout = QHBoxLayout(self)
        self.widget_layout.setContentsMargins(0, 0, 0, 0)

        style = f"""
        #bg_frame {{
            border-radius: {THEME.border_radius};
            background-color: {THEME.color.color4};
        }}
        .QLabel {{
            font: {THEME.font.text_size}pt "{THEME.font.family}";
            color: {THEME.font_color};
            padding-left: 10px;
            padding-right: 10px;
        }}
        """

        self.bg_frame = QFrame()
        self.bg_frame.setObjectName("bg_frame")
        self.bg_frame.setStyleSheet(style)

        self.widget_layout.addWidget(self.bg_frame)

        self.bg_layout = QHBoxLayout(self.bg_frame)
        self.bg_layout.setContentsMargins(0, 0, 0, 0)

        self.copyright_label = QLabel(self.copyright)
        self.copyright_label.setAlignment(Qt.AlignVCenter)  # type: ignore

        self.version_label = QLabel(self.version)
        self.version_label.setAlignment(Qt.AlignVCenter)  # type: ignore

        self.separator = QSpacerItem(20, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)  # type: ignore

        self.bg_layout.addWidget(self.copyright_label)
        self.bg_layout.addSpacerItem(self.separator)
        self.bg_layout.addWidget(self.version_label)



from kivy.app import App
from kivy.uix.button import Button
from kivy.uix.boxlayout import BoxLayout
from kivy.uix.label import Label

class MyApp(App):
    def build(self):
        self.layout = BoxLayout(orientation='vertical')
        self.label = Label(text='Hello, Kivy!')
        self.button = Button(text='Click Me!')

        self.button.bind(on_press=self.on_button_click)

        self.layout.add_widget(self.label)
        self.layout.add_widget(self.button)

        return self.layout

    def on_button_click(self, instance):
        self.label.text = 'Button Clicked!'

if __name__ == '__main__':
    MyApp().run()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description:
# @Time   : 2024-08-16 17:05
# @Author : 毛鹏
from PySide6.QtWidgets import QVBoxLayout

from mango_ui.init import QStackedWidget, QApplication, QMetaObject, Qt
from mango_ui.settings.settings import THEME
from mango_ui.widgets.display.mango_label import MangoLabel


class PagesWindow:

    def __init__(self, parent, content_area_left_frame, page_dict):
        self.parent = parent
        self.content_area_left_frame = content_area_left_frame
        self.page_dict = page_dict

        self.loading_indicator = MangoLabel("数据加载中...")
        self.loading_indicator.setAlignment(Qt.AlignCenter)  # type: ignore
        self.loading_indicator.setStyleSheet(f"font-size: 16px; color: {THEME.icon_color};")

        self.main_pages_layout = QVBoxLayout(self.content_area_left_frame)
        self.main_pages_layout.setSpacing(0)
        self.main_pages_layout.setContentsMargins(0, 0, 0, 0)
        self.pages = QStackedWidget(self.content_area_left_frame)
        self.main_pages_layout.addWidget(self.pages)
        QMetaObject.connectSlotsByName(self.content_area_left_frame)

    def set_page(self, page: str, data: dict | None = None):
        self.pages.addWidget(self.loading_indicator)
        self.pages.setCurrentWidget(self.loading_indicator)
        QApplication.processEvents()

        page_class = self.page_dict.get(page)
        if page_class is not None:
            page = page_class(self.parent)
        else:
            return
        current_widget = self.pages.currentWidget()
        if current_widget and current_widget != self.loading_indicator:
            self.pages.removeWidget(current_widget)
        if data is not None and isinstance(data, dict):
            page.data = data
        else:
            page.data = {}
        if hasattr(page, 'show_data'):
            page.show_data()
        self.pages.addWidget(page)
        self.pages.setCurrentWidget(page)
        self.pages.removeWidget(self.loading_indicator)



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-08-28 16:33
# @Author : 毛鹏
from mango_ui import *
from mango_ui.init import *


class ComponentPage(QWidget):
    def __init__(self, parent):
        super().__init__()
        self.parent = parent
        self.layout = QVBoxLayout(self)
        self.layout.setSpacing(5)
        self.layout.setContentsMargins(5, 5, 5, 5)

        self.scroll_area = MangoScrollArea(vertical_off=True, horizontal_off=True)

        self.contents = QWidget()
        self.contents.setGeometry(QRect(0, 0, 840, 580))
        self.contents.setStyleSheet(u"background: transparent;")
        self.verticalLayout = QVBoxLayout(self.contents)
        self.verticalLayout.setSpacing(15)
        self.verticalLayout.setContentsMargins(5, 5, 5, 5)
        self.title_label = QLabel(self.contents)
        self.title_label.setText(QCoreApplication.translate("PagesWindow", u"页面组件", None))

        self.title_label.setMaximumSize(QSize(16777215, 40))
        font = QFont()
        font.setPointSize(16)
        self.title_label.setFont(font)
        self.title_label.setStyleSheet(u"font-size: 16pt")
        self.title_label.setAlignment(Qt.AlignCenter)
        self.verticalLayout.addWidget(self.title_label)
        self.description_label = QLabel(self.contents)
        self.description_label.setAlignment(Qt.AlignHCenter | Qt.AlignTop)
        self.description_label.setText(QCoreApplication.translate("组件中心",
                                                                  u"以下是所有自定义小部件\n"
                                                                  "哈哈哈哈哈",
                                                                  None))
        self.description_label.setWordWrap(True)
        self.verticalLayout.addWidget(self.description_label)
        self.scroll_area.setWidget(self.contents)

        self.layout.addWidget(self.scroll_area)

    def load_data(self):
        # 模拟延迟加载数据
        QTimer.singleShot(3000, self.show_data)  # 3秒后调用show_data方法

    def show_data(self):
        pass



from mango_ui.models.models import AppConfig, MenusModel, Theme

qss_dict = {
    "theme_name": "Default",  # 主题名称
    "font_color": "#000000",  # 字体颜色
    "font_family": "Arial",  # 字体
    "font_size": "12px",  # 字体大小
    "font_weight": "normal",  # 字体粗细

    "icon_color": "#000000",  # icon颜色
    "icon_hover": "#353037",  # icon悬停
    "icon_pressed": "#626062",  # icon按下
    "icon_active": "#000000",  # icon松开

    "card_color": "#E5E6EB",  # 卡片颜色

    "color": {  # 主题色
        "color0": "#ffffff",
        "color1": "#F7F8Fa",
        "color2": "#F2F3F5",
        "color3": "#E5E6EB",
        "color4": "#C9CDD4",
        "color5": "#A9AEB8",
        "color6": "#86909C",
        "color7": "#6B7785",
        "color8": "#4E5969",
        "color9": "#272E3B",
        "color10": "#1D2129",
    },

    "background_color": "#ffffff",  # 背景颜色
    "border": "#EAEAEA",  # 边框
    "border_radius": "8px",  # 边框圆角
    "padding": "5px",  # 内边距
    "margin": "5px",  # 外边距
    "width": "100px",  # 宽度
    "height": "30px",  # 高度
    "text_align": "center",  # 文本对齐
    "line_height": "30px",  # 行高
    "group": {
        "info": "#3491FA",
        "warning": "#F9925A",
        "success": "#1EBF6E",
        "error": "#DF4C52",
    },
    "hover": {  # 悬停状态
        "background_color": "#F2F3F5",
        "color": "#000000",
    },
    "pressed": {  # 按下状态
        "background_color": "#A9AEB8",
        "color": "#000000",
    },
    "disabled": {  # 禁用状态
        "background_color": "#4E5969",
        "color": "#000000",
    },
    "font": {
        "family": "微软雅黑",
        "title_size": 11,
        "text_size": 10
    }
}

THEME = Theme(**qss_dict)

STYLE = AppConfig(**{
    "app_name": "芒果测试平台",
    "version": "3.5.1",
    "copyright": "Copyright © By: 芒果味  2022-2024",
    "year": 2021,
    "theme_name": "mango",
    "custom_title_bar": True,
    "lef_menu_size": {
        "minimum": 50,
        "maximum": 240
    },
    "left_menu_content_margins": 1,
    "left_column_size": {
        "minimum": 0,
        "maximum": 240
    },
    "right_column_size": {
        "minimum": 0,
        "maximum": 240
    },
})

MENUS = MenusModel(**{
    "left_menus": [
        {
            "btn_icon": ":/icons/home.svg",
            "btn_id": "home",
            "btn_text": "首页",
            "btn_tooltip": "首页",
            "show_top": True,
            "is_active": True
        },
        {
            "btn_icon": ":/icons/app_icon.svg",
            "btn_id": "layout",
            "btn_text": "布局",
            "btn_tooltip": "布局",
            "show_top": True,
            "is_active": False,
            "submenus": [
                {
                    "btn_id": "layout_page_1",
                    "btn_text": "布局1",
                    "btn_tooltip": "布局1",
                    "show_top": True,
                    "is_active": False
                },
                {
                    "btn_id": "layout_page_2",
                    "btn_text": "布局2",
                    "btn_tooltip": "布局2",
                    "show_top": True,
                    "is_active": False
                },

            ]
        },
        {
            "btn_icon": ":/icons/calendar_clock.svg",
            "btn_id": "input",
            "btn_text": "输入",
            "btn_tooltip": "输入",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/command.svg",
            "btn_id": "feedback",
            "btn_text": "反馈",
            "btn_tooltip": "反馈消息",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/compass.svg",
            "btn_id": "component",
            "btn_text": "公共",
            "btn_tooltip": "公共组件",
            "show_top": True,
            "is_active": False,
            "submenus": [
                {
                    "btn_id": "component_page_3",
                    "btn_text": "布局3",
                    "btn_tooltip": "布局3",
                    "show_top": True,
                    "is_active": False
                },
                {
                    "btn_id": "component_page_4",
                    "btn_text": "布局4",
                    "btn_tooltip": "布局4",
                    "show_top": True,
                    "is_active": False
                },

            ]
        },
        {
            "btn_icon": ":/icons/down.svg",
            "btn_id": "container",
            "btn_text": "容器",
            "btn_tooltip": "容器",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/fill.svg",
            "btn_id": "charts",
            "btn_text": "图表",
            "btn_tooltip": "图表",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/home.svg",
            "btn_id": "display",
            "btn_text": "显示",
            "btn_tooltip": "显示",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_add_user.svg",
            "btn_id": "graphics",
            "btn_text": "图形",
            "btn_tooltip": "图形",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_arrow_left.svg",
            "btn_id": "menu",
            "btn_text": "菜单",
            "btn_tooltip": "菜单",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_arrow_right.svg",
            "btn_id": "window",
            "btn_text": "窗口",
            "btn_tooltip": "窗口",
            "show_top": True,
            "is_active": False
        },
        {
            "btn_icon": ":/icons/icon_info.svg",
            "btn_id": "其他",
            "btn_text": "菜单",
            "btn_tooltip": "菜单",
            "show_top": True,
            "is_active": False
        },

    ],
    "title_bar_menus": [
        {
            "btn_icon": ":/icons/project.ico",
            "btn_id": "project",
            "btn_tooltip": "请选择项目",
            "is_active": False
        }, {
            "btn_icon": ":/icons/env.ico",
            "btn_id": "test_env",
            "btn_tooltip": "请选择测试环境",
            "is_active": False
        }
    ]
})

dd = {
    "theme_name": "Default",
    "radius": "8",
    "border_size": "1",
    "dark_one": "#9d83a4",
    "dark_two": "#dad1dd",
    "dark_three": "#EDEDED",
    "dark_four": "#A8A8A8",
    "bg_one": "#ffffff",
    "bg_two": "#c2b2c6",
    "bg_three": "#A8A8A8",

    "icon_color": "#000000",
    "icon_hover": "#353037",
    "icon_pressed": "#626062",
    "icon_active": "#000000",

    "context_color": "#6db65a",
    "context_hover": "#c2b2c6",
    "context_pressed": "#a993af",

    "text_title": "#000000",
    "text_foreground": "#000000",
    "text_description": "#000000",
    "text_active": "#000000",
    "white": "#ffffff",
    "pink": "#FF82AB",
    "green": "#00FF7F",
    "red": "#EE3B3B",
    "yellow": "#fdb933",
    "blue": "#33a3dc",
    "orange": "#faa755",
    "font": {
        "family": "微软雅黑",
        "title_size": 11,
        "text_size": 10
    }
}



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-01 下午10:01
# @Author : 毛鹏
from mango_ui.init import *


class MangoMessage(QWidget):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.Tool | Qt.WindowStaysOnTopHint)  # 保持在最上面
        self.setFixedHeight(30)

        self.layout = QHBoxLayout(self)
        self.layout.setContentsMargins(0, 0, 0, 0)
        # 设置背景颜色和边框
        self.setStyleSheet(f"background-color: {style}; border-radius: 10px;")

        # 根据文字长度调整宽度
        self.label = QLabel(message)
        self.layout.addStretch(1)
        self.layout.addWidget(self.label, 8)
        self.layout.addStretch(1)
        font_metrics = QFontMetrics(self.label.font())
        text_width = font_metrics.boundingRect(message).width() + 25
        self.setFixedWidth(text_width)

        # 设置渐隐效果
        self.animation = QPropertyAnimation(self, b"windowOpacity")
        self.animation.setDuration(1500)
        self.animation.setStartValue(1.0)
        self.animation.setEndValue(0.0)
        self.animation.finished.connect(self.close)
        self.animation.start()

        self.hovered = False

    # @staticmethod
    # def create_colored_icon(color) -> QIcon:
    #     # 创建一个透明的 QPixmap
    #     pixmap = QPixmap(32, 32)  # 设置图标的大小
    #     pixmap.fill(Qt.transparent)
    #
    #     # 使用 QPainter 绘制图标
    #     painter = QPainter(pixmap)
    #     painter.setRenderHint(QPainter.Antialiasing)
    #
    #     # 这里可以加载原始图标
    #     original_icon = QPixmap(":/icons/app_icon.png")  # 替换为你的图标路径
    #     painter.drawPixmap(0, 0, original_icon)
    #
    #     # 设置颜色
    #     painter.setCompositionMode(QPainter.CompositionMode_SourceIn)
    #     painter.fillRect(pixmap.rect(), QColor(color))
    #     painter.end()
    #
    #     return QIcon(pixmap)

    def enterEvent(self, event):
        """鼠标进入事件，暂停渐隐动画"""
        if self.hovered is False:
            self.hovered = True
            self.animation.stop()

    def leaveEvent(self, event):
        """鼠标离开事件，重新开始渐隐动画"""
        if self.hovered is True:
            self.hovered = False
            self.animation.start()



# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2024-09-01 下午9:53
# @Author : 毛鹏
from mango_ui.init import *


class MangoNotification(QFrame):
    def __init__(self, parent, message, style):
        super().__init__(parent)
        self.style = style
        self.setWindowFlags(Qt.FramelessWindowHint | Qt.WindowStaysOnTopHint | Qt.Tool)
        self.setFixedSize(240, 80)
        self.setObjectName("MangoNotification")

        self.layout = QVBoxLayout(self)
        self.layout.setContentsMargins(10, 0, 0, 0)
        self.layout.addWidget(QLabel(message))
        self.setFrameShape(QFrame.NoFrame)

        # 设置微红色背景色
        self.set_style()
        # 设置渐隐效果
        self.animation = QPropertyAnimation(self, b"windowOpacity")
        self.animation.setDuration(1500)
        self.animation.setStartValue(1.0)
        self.animation.setEndValue(0.0)
        self.animation.finished.connect(self.close)
        self.animation.start()
        self.hovered = False

    def enterEvent(self, event):
        """鼠标进入事件，暂停渐隐动画"""
        if self.hovered is False:
            self.hovered = True
            self.animation.stop()  # 停止动画

    def leaveEvent(self, event):
        """鼠标离开事件，重新开始渐隐动画"""
        if self.hovered is True:
            self.hovered = False
            self.animation.start()  # 重新开始动画

    def set_style(self):
        self.setStyleSheet(f"""
            QFrame#MangoNotification {{
                background-color: {self.style};
                border-radius: 10px;
                border: 1px solid black;
            }}
        """)
